import { NodeOptions } from '@highlight-run/node';
import { IncomingHttpHeaders } from 'http';
import { NextConfig } from 'next';

declare function registerHighlight(nodeOptions: NodeOptions): Promise<void>;

declare interface Metric {
    name: string;
    value: number;
    tags?: {
        name: string;
        value: string;
    }[];
}
interface HighlightInterface {
    init: (options: NodeOptions) => void;
    isInitialized: () => boolean;
    metrics: (metrics: Metric[]) => void;
}
declare const H: HighlightInterface;
declare type HasHeaders = {
    headers: IncomingHttpHeaders;
};
declare type HasStatus = {
    statusCode: number;
    statusMessage: string;
};
declare type ApiHandler<T extends HasHeaders, S extends HasStatus> = (req: T, res: S) => unknown | Promise<unknown>;
declare const Highlight: (options: NodeOptions) => <T extends HasHeaders, S extends HasStatus>(origHandler: ApiHandler<T, S>) => ApiHandler<T, S>;

interface HighlightConfigOptions {
    uploadSourceMaps?: boolean;
    configureHighlightProxy?: boolean;
    apiKey?: string;
    appVersion?: string;
    sourceMapsPath?: string;
    sourceMapsBasePath?: string;
}
declare type NextConfigObject = NextConfig;
declare type NextConfigFunction = (phase: string, { defaultConfig }: {
    defaultConfig: any;
}) => NextConfig;
declare type NextConfigAsyncFunction = (phase: string, { defaultConfig }: {
    defaultConfig: any;
}) => Promise<NextConfig>;
declare type NextConfigInput = NextConfigObject | NextConfigFunction | NextConfigAsyncFunction;
declare const withHighlightConfig: (config: NextConfigInput, highlightOpts?: HighlightConfigOptions) => Promise<NextConfig>;

export { H, Highlight, registerHighlight, withHighlightConfig };
