"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  H: () => H,
  Highlight: () => Highlight,
  registerHighlight: () => registerHighlight,
  withHighlightConfig: () => withHighlightConfig
});
module.exports = __toCommonJS(src_exports);

// src/util/registerHighlight.ts
async function registerHighlight(nodeOptions) {
  if (process.env.NEXT_RUNTIME === "nodejs") {
    const { H: H2 } = await import("@highlight-run/node");
    H2.init(nodeOptions);
  } else {
    console.info(
      `Highlight not registered: NEXT_RUNTIME=${process.env.NEXT_RUNTIME}`
    );
  }
}

// src/util/withHighlight.ts
var import_node = require("@highlight-run/node");
var H = {
  init: (options) => {
    if (!import_node.H.isInitialized()) {
      import_node.H.init(options);
    }
  },
  isInitialized: () => import_node.H.isInitialized(),
  metrics: (metrics, opts) => {
    const h = global.__HIGHLIGHT__;
    if (h && !opts) {
      opts = h;
    }
    if (!(opts == null ? void 0 : opts.secureSessionId)) {
      return console.warn(
        "H.metrics session could not be inferred the handler context."
      );
    }
    for (const m of metrics) {
      import_node.H.recordMetric(
        opts.secureSessionId,
        m.name,
        m.value,
        opts.requestId,
        m.tags
      );
    }
  }
};
var Highlight = (options) => (origHandler) => {
  return async (req, res) => {
    if (!import_node.H.isInitialized()) {
      import_node.H.init(options);
    }
    const processHighlightHeaders = () => {
      if (req.headers && req.headers[import_node.HIGHLIGHT_REQUEST_HEADER]) {
        const [secureSessionId2, requestId2] = `${req.headers[import_node.HIGHLIGHT_REQUEST_HEADER]}`.split("/");
        if (secureSessionId2 && requestId2) {
          ;
          global.__HIGHLIGHT__ = { secureSessionId: secureSessionId2, requestId: requestId2 };
          return { secureSessionId: secureSessionId2, requestId: requestId2 };
        }
      }
      return { secureSessionId: void 0, requestId: void 0 };
    };
    const { secureSessionId, requestId } = processHighlightHeaders();
    const start = new Date();
    try {
      return await origHandler(req, res);
    } catch (e) {
      import_node.H.consumeEvent(secureSessionId);
      if (e instanceof Error) {
        import_node.H.consumeError(e, secureSessionId, requestId);
        await import_node.H.flush();
      }
      res.statusCode = 500;
      res.statusMessage = "Internal Server Error";
      throw e;
    } finally {
      const delta = (new Date().getTime() - start.getTime()) * 1e6;
      const { secureSessionId: secureSessionId2, requestId: requestId2 } = processHighlightHeaders();
      if (secureSessionId2) {
        import_node.H.recordMetric(
          secureSessionId2,
          "latency",
          delta,
          requestId2
        );
        await import_node.H.flush();
      }
    }
  };
};

// src/util/highlightWebpackPlugin.ts
var import_lib = require("@highlight-run/sourcemap-uploader/dist/lib");
var HighlightWebpackPlugin = class {
  apiKey;
  appVersion;
  path;
  basePath;
  constructor(apiKey, appVersion, path, basePath) {
    this.apiKey = apiKey;
    this.appVersion = appVersion;
    this.path = path;
    this.basePath = basePath;
  }
  apply(compiler) {
    compiler.hooks.afterEmit.tap("HighlightWebpackPlugin", () => {
      (0, import_lib.uploadSourcemaps)({
        apiKey: this.apiKey,
        appVersion: this.appVersion,
        path: this.path,
        basePath: this.basePath
      });
    });
    return compiler;
  }
};

// src/util/withHighlightConfig.ts
var getDefaultOpts = async (config, highlightOpts) => {
  const isProdBuild = process.env.NODE_ENV === "production";
  const hasSourcemapApiKey = !!process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY || !!(highlightOpts == null ? void 0 : highlightOpts.apiKey);
  let version = null;
  if (config.generateBuildId) {
    const buildId = config.generateBuildId();
    if (typeof buildId === "string") {
      version = buildId;
    } else {
      version = await buildId;
    }
  }
  return {
    uploadSourceMaps: isProdBuild && ((highlightOpts == null ? void 0 : highlightOpts.uploadSourceMaps) ?? (!config.productionBrowserSourceMaps && hasSourcemapApiKey)),
    configureHighlightProxy: (highlightOpts == null ? void 0 : highlightOpts.configureHighlightProxy) ?? true,
    apiKey: (highlightOpts == null ? void 0 : highlightOpts.apiKey) ?? "",
    appVersion: (highlightOpts == null ? void 0 : highlightOpts.appVersion) ?? version ?? "",
    sourceMapsPath: (highlightOpts == null ? void 0 : highlightOpts.sourceMapsPath) ?? ".next/",
    sourceMapsBasePath: (highlightOpts == null ? void 0 : highlightOpts.sourceMapsBasePath) ?? "_next/"
  };
};
var getHighlightConfig = async (config, highlightOpts) => {
  const defaultOpts = await getDefaultOpts(config, highlightOpts);
  let newRewrites = config.rewrites;
  if (defaultOpts.uploadSourceMaps || defaultOpts.configureHighlightProxy) {
    newRewrites = async () => {
      let re;
      if (!config.rewrites) {
        re = new Array();
      } else {
        re = await config.rewrites();
      }
      const sourcemapRewrite = {
        source: "/:path*.map",
        destination: "/404"
      };
      const highlightRewrite = {
        source: "/highlight-events",
        destination: "https://pub.highlight.run"
      };
      if (!re || Array.isArray(re)) {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? [sourcemapRewrite] : [],
          afterFiles: defaultOpts.configureHighlightProxy ? (re ?? []).concat(highlightRewrite) : [],
          fallback: []
        };
      } else {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? (re.beforeFiles ?? []).concat(sourcemapRewrite) : re.beforeFiles,
          afterFiles: defaultOpts.configureHighlightProxy ? (re.afterFiles ?? []).concat(highlightRewrite) : re.afterFiles,
          fallback: re.fallback
        };
      }
    };
  }
  let newWebpack = config.webpack;
  if (defaultOpts.uploadSourceMaps) {
    newWebpack = (webpackConfig, opts) => {
      let originalConfig = webpackConfig;
      if (config.webpack) {
        originalConfig = config.webpack(webpackConfig, opts);
      }
      originalConfig.plugins.push(
        new HighlightWebpackPlugin(
          defaultOpts.apiKey,
          defaultOpts.appVersion,
          defaultOpts.sourceMapsPath,
          defaultOpts.sourceMapsBasePath
        )
      );
      return originalConfig;
    };
  }
  return {
    ...config,
    productionBrowserSourceMaps: defaultOpts.uploadSourceMaps || config.productionBrowserSourceMaps,
    rewrites: newRewrites,
    webpack: newWebpack
  };
};
var withHighlightConfig = async (config, highlightOpts) => {
  if (typeof config === "function") {
    return async (phase, { defaultConfig }) => {
      const userNextConfigObject = config(phase, { defaultConfig });
      if (typeof userNextConfigObject === "function") {
        const nc = await userNextConfigObject;
        return await getHighlightConfig(nc, highlightOpts);
      } else {
        return await getHighlightConfig(
          userNextConfigObject,
          highlightOpts
        );
      }
    };
  } else {
    return await getHighlightConfig(config, highlightOpts);
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  H,
  Highlight,
  registerHighlight,
  withHighlightConfig
});
